@@ -48,76 +48,93 @@ my %ignore_used;
 my @ignore_line;
 
 my %banfunc = (
-    "gmtime" => 1,
-    "localtime" => 1,
-    "gets" => 1,
-    "strtok" => 1,
-    "sprintf" => 1,
-    "snprintf" => 1,
-    "vsprintf" => 1,
-    "vsnprintf" => 1,
+    "_access" => 1,
+    "_lseeki64" => 1,
+    "_mbscat" => 1,
+    "_mbsncat" => 1,
+    "_open" => 1,
+    "_tcscat" => 1,
+    "_tcsdup" => 1,
+    "_tcsncat" => 1,
+    "_tcsncpy" => 1,
+    "_waccess" => 1,
+    "_wcscat" => 1,
+    "_wcsdup" => 1,
+    "_wcsncat" => 1,
+    "_wfopen" => 1,
+    "_wfreopen" => 1,
+    "_wopen" => 1,
+    "accept" => 1,
+    "accept4" => 1,
+    "access" => 1,
     "aprintf" => 1,
+    "atoi" => 1,
+    "atol" => 1,
+    "calloc" => 1,
+    "close" => 1,
+    "CreateFile" => 1,
+    "CreateFileA" => 1,
+    "CreateFileW" => 1,
+    "fclose" => 1,
+    "fdopen" => 1,
+    "fopen" => 1,
     "fprintf" => 1,
+    "free" => 1,
+    "freeaddrinfo" => 1,
+    "freopen" => 1,
+    "getaddrinfo" => 1,
+    "gets" => 1,
+    "gmtime" => 1,
+    "llseek" => 1,
+    "LoadLibrary" => 1,
+    "LoadLibraryA" => 1,
+    "LoadLibraryEx" => 1,
+    "LoadLibraryExA" => 1,
+    "LoadLibraryExW" => 1,
+    "LoadLibraryW" => 1,
+    "localtime" => 1,
+    "lseek" => 1,
+    "malloc" => 1,
+    "mbstowcs" => 1,
+    "MoveFileEx" => 1,
+    "MoveFileExA" => 1,
+    "MoveFileExW" => 1,
     "msnprintf" => 1,
     "mvsnprintf" => 1,
+    "open" => 1,
     "printf" => 1,
-    "vaprintf" => 1,
-    "vfprintf" => 1,
-    "vprintf" => 1,
+    "realloc" => 1,
+    "recv" => 1,
+    "rename" => 1,
+    "send" => 1,
+    "snprintf" => 1,
+    "socket" => 1,
+    "socketpair" => 1,
+    "sprintf" => 1,
     "sscanf" => 1,
+    "stat" => 1,
     "strcat" => 1,
+    "strcpy" => 1,
+    "strdup" => 1,
     "strerror" => 1,
     "strncat" => 1,
     "strncpy" => 1,
     "strtok_r" => 1,
+    "strtok" => 1,
     "strtol" => 1,
     "strtoul" => 1,
-    "atoi" => 1,
-    "atol" => 1,
-    "_mbscat" => 1,
-    "_mbsncat" => 1,
-    "_tcscat" => 1,
-    "_tcsdup" => 1,
-    "_tcsncpy" => 1,
-    "_tcsncat" => 1,
-    "_wcscat" => 1,
-    "_wcsncat" => 1,
-    "_wcsdup" => 1,
-    "wcsdup" => 1,
+    "vaprintf" => 1,
+    "vfprintf" => 1,
+    "vprintf" => 1,
+    "vsnprintf" => 1,
+    "vsprintf" => 1,
     "wcscpy" => 1,
+    "wcsdup" => 1,
     "wcsncpy" => 1,
-    "mbstowcs" => 1,
     "wcstombs" => 1,
-    "LoadLibrary" => 1,
-    "LoadLibraryA" => 1,
-    "LoadLibraryW" => 1,
-    "LoadLibraryEx" => 1,
-    "LoadLibraryExA" => 1,
-    "LoadLibraryExW" => 1,
     "WSASocket" => 1,
     "WSASocketA" => 1,
     "WSASocketW" => 1,
-    "_waccess" => 1,
-    "_access" => 1,
-    "access" => 1,
-    "accept" => 1,
-    "accept4" => 1,
-    "freeaddrinfo" => 1,
-    "getaddrinfo" => 1,
-    "recv" => 1,
-    "send" => 1,
-    "socket" => 1,
-    "socketpair" => 1,
-    "fclose" => 1,
-    "fdopen" => 1,
-    "fopen" => 1,
-    "freopen" => 1,
-    "open" => 1,
-    "_open" => 1,
-    "_wfopen" => 1,
-    "_wfreopen" => 1,
-    "_wopen" => 1,
-    "stat" => 1,
     );
 
 my %warnings_extended = (
@@ -136,11 +153,12 @@ my %warnings = (
     'BRACEPOS'              => 'wrong position for an open brace',
     'BRACEWHILE'            => 'A single space between open brace and while',
     'COMMANOSPACE'          => 'comma without following space',
-    "CLOSEBRACE"            => 'close brace indent level vs line above is off',
+    'CLOSEBRACE'            => 'close brace indent level vs line above is off',
     'COMMENTNOSPACEEND'     => 'no space before */',
     'COMMENTNOSPACESTART'   => 'no space following /*',
     'COPYRIGHT'             => 'file missing a copyright statement',
     'CPPCOMMENTS'           => '// comment detected',
+    'CPPSPACE'              => 'space before preprocessor hash',
     'DOBRACE'               => 'A single space between do and open brace',
     'EMPTYLINEBRACE'        => 'Empty line before the open brace',
     'EQUALSNOSPACE'         => 'equals sign without following space',
@@ -150,6 +168,7 @@ my %warnings = (
     'EXCLAMATIONSPACE'      => 'Whitespace after exclamation mark in expression',
     'FIXME'                 => 'FIXME or TODO comment',
     'FOPENMODE'             => 'fopen needs a macro for the mode string',
+    'IFDEFSINGLE',          => 'use ifdef/ifndef for single macro checks',
     'INCLUDEDUP',           => 'same file is included again',
     'INDENTATION'           => 'wrong start column for code',
     'LONGLINE'              => "Line longer than $max_column",
@@ -646,6 +665,11 @@ sub scanfile {
                       $line, length($1), $file, $l, "\/\/ comment");
         }
 
+        if($l =~ /^\s*#\s*if\s+!?\s*defined\([a-zA-Z0-9_]+\)$/) {
+            checkwarn("IFDEFSINGLE",
+                      $line, length($1), $file, $l, "use ifdef/ifndef for single macro checks");
+        }
+
         if($l =~ /^(\#\s*include\s+)([\">].*[>}"])/) {
             my ($pre, $path) = ($1, $2);
             if($includes{$path}) {
@@ -655,6 +679,11 @@ sub scanfile {
             $includes{$path} = $l;
         }
 
+        # detect leading space before the hash
+        if($l =~ /^([ \t]+)\#/) {
+            checkwarn("CPPSPACE",
+                      $line, 0, $file, $l, "space before preprocessor hash");
+        }
         # detect and strip preprocessor directives
         if($l =~ /^[ \t]*\#/) {
             # preprocessor line
@@ -947,9 +976,11 @@ sub scanfile {
             my $bad = $2;
             my $prefix = $1;
             my $suff = $3;
-            checkwarn("BANNEDFUNC",
-                      $line, length($prefix), $file, $ol,
-                      "use of $bad is banned");
+            if($prefix !~ /(->|\.)$/) {
+                checkwarn("BANNEDFUNC",
+                          $line, length($prefix), $file, $ol,
+                          "use of $bad is banned");
+            }
             my $search = quotemeta($prefix . $bad . $suff);
             my $replace = $prefix . 'x' x (length($bad) + 1);
             $l =~ s/$search/$replace/;
@@ -1200,7 +1231,6 @@ sub scanfile {
 
 }
 
-
 if($errors || $warnings || $verbose) {
     printf "checksrc: %d errors and %d warnings\n", $errors, $warnings;
     if($suppressed) {
